@@ -147,10 +147,14 @@ def PlotNetworkXGraph(
 
     figure, axes = FigureAndAxesFromBoth(figure, axes, 2)
 
+    if NodePositions is None:
+        node_positions = None
+    else:
+        node_positions = NodePositions(axes)
     _PlotWithNetworkX(
         graph,
         axes,
-        node_positions=NodePositions(axes),
+        node_positions=node_positions,
         node_colors=node_colors,
         with_node_labels=with_node_labels,
         node_font_size=node_font_size,
@@ -285,15 +289,13 @@ def _PlotWithNetworkX(
         **options,
     )
 
-    if edge_labels is not None:
-        options = {}
-        if node_positions is not None:
-            options["pos"] = node_positions
-        options["edge_labels"] = edge_labels
+    if (edge_labels is not None) and (node_positions is not None):
+        options = {"edge_labels": edge_labels}
         if edge_font_size is not None:
             options["font_size"] = edge_font_size
         ntkx.draw_networkx_edge_labels(
             graph,
+            node_positions,
             ax=axes,
             **options,
         )
