@@ -48,6 +48,9 @@ from skl_graph.type.node import branch_node_t, end_node_t, node_t
 array_t = nmpy.ndarray
 
 
+_MAX_COORDINATE_INTERPOLATION_ERROR = 0.8
+
+
 class measures_t(named_tuple_t):
     """
     segment_: prefix for pixel-to-pixel segments
@@ -125,7 +128,7 @@ class edge_t(raw_edge_t):
                 as_list: list[float] = list(self.measures.segment_lengths)
                 arc_lengths = nmpy.cumsum([0.0] + as_list)
                 self._cache[cache_entry] = tuple(
-                    spnt.PchipInterpolator(arc_lengths, self.sites[idx_])
+                    _PchipInterpolator(arc_lengths, self.sites[idx_])
                     for idx_ in range(self.dim)
                 )
             else:
@@ -182,7 +185,23 @@ class edge_t(raw_edge_t):
         cache_entry = self.Curvatures.__name__
 
         if cache_entry not in self._cache:
-            curvatures = []
+            as_curve = self.AsCurve()
+            arc_lengths = as_curve[0].x
+            # derivatives_?: first index=0, 1 for derivative orders 1, 2; second index=arc-length parameter
+            derivatives_x, derivatives_y = (
+                tuple(as_curve[_idx](arc_lengths, _rdr) for _rdr in (1, 2))
+                for _idx in range(self.dim)
+            )
+
+            normalization = (derivatives_x[0] ** 2 + derivatives_y[0] ** 2) ** 1.5
+            where_safe = normalization != 0.0
+            curvatures = nmpy.empty_like(arc_lengths)
+            curvatures[where_safe] = (
+                derivatives_x[0][where_safe] * derivatives_y[1][where_safe]
+                - derivatives_y[0][where_safe] * derivatives_x[1][where_safe]
+            ) / normalization[where_safe]
+            curvatures[nmpy.logical_not(where_safe)] = 0.0
+
             self._cache[cache_entry] = tuple(curvatures)
 
         return self._cache[cache_entry]
@@ -242,6 +261,12 @@ class edge_t(raw_edge_t):
 
             where_safe = abc_sq_length != 0.0
             torsions = nmpy.empty_like(arc_lengths)
+            # Why abs? From: https://mathworld.wolfram.com/Torsion.html
+            #     The torsion is positive for a right-handed curve, [...]
+            # From : https://mathcurve.com/courbes3d.gb/dextre/dextre.shtml
+            #     A right-handed curve is a curve with positive torsion
+            # (!)
+            # Anyway, this explains why abs.
             torsions[where_safe] = nmpy.abs(
                 (
                     derivatives_x[2][where_safe] * a[where_safe]
@@ -663,3 +688,23 @@ def _LMapNeighborhood(lmap: array_t, site: tuple[int, ...]) -> tuple[array_t, ar
     neighborhood = lmap[slices]
 
     return nmpy.array(slices_starts, dtype=nmpy.int64), neighborhood
+
+
+def _PchipInterpolator(
+    arc_lengths: array_t, coordinates: array_t, /
+) -> spnt.PchipInterpolator:
+    """"""
+    for n_samples in range(2, arc_lengths.size + 1):
+        samples = nmpy.linspace(0, arc_lengths.size - 1, num=n_samples)
+        indices = nmpy.unique(nmpy.around(samples)).astype(nmpy.uint64)
+        output = spnt.PchipInterpolator(
+            arc_lengths[indices], coordinates[indices], extrapolate=False
+        )
+
+        error = max(abs(output(arc_lengths) - coordinates))
+        if error <= _MAX_COORDINATE_INTERPOLATION_ERROR:
+            return output
+
+    raise RuntimeError(
+        f"{arc_lengths} -> {coordinates}: Unable to interpolate with sufficient precision."
+    )
